@@ -32,7 +32,6 @@
 
 #include "suricata-common.h"
 #include "threads.h"
-#include "debug.h"
 #include "decode.h"
 #include "detect.h"
 
@@ -98,13 +97,11 @@ void DetectHttpMethodRegister(void)
     sigmatch_table[DETECT_HTTP_METHOD].Setup = DetectHttpMethodSetupSticky;
     sigmatch_table[DETECT_HTTP_METHOD].flags |= SIGMATCH_NOOPT|SIGMATCH_INFO_STICKY_BUFFER;
 
-    DetectAppLayerInspectEngineRegister2("http_method", ALPROTO_HTTP,
-            SIG_FLAG_TOSERVER, HTP_REQUEST_LINE,
-            DetectEngineInspectBufferGeneric, GetData);
+    DetectAppLayerInspectEngineRegister2("http_method", ALPROTO_HTTP1, SIG_FLAG_TOSERVER,
+            HTP_REQUEST_LINE, DetectEngineInspectBufferGeneric, GetData);
 
-    DetectAppLayerMpmRegister2("http_method", SIG_FLAG_TOSERVER, 4,
-            PrefilterGenericMpmRegister, GetData, ALPROTO_HTTP,
-            HTP_REQUEST_LINE);
+    DetectAppLayerMpmRegister2("http_method", SIG_FLAG_TOSERVER, 4, PrefilterGenericMpmRegister,
+            GetData, ALPROTO_HTTP1, HTP_REQUEST_LINE);
 
     DetectAppLayerInspectEngineRegister2("http_method", ALPROTO_HTTP2, SIG_FLAG_TOSERVER,
             HTTP2StateDataClient, DetectEngineInspectBufferGeneric, GetData2);
@@ -136,10 +133,8 @@ void DetectHttpMethodRegister(void)
  */
 static int DetectHttpMethodSetup(DetectEngineCtx *de_ctx, Signature *s, const char *str)
 {
-    return DetectEngineContentModifierBufferSetup(de_ctx, s, str,
-                                                  DETECT_AL_HTTP_METHOD,
-                                                  g_http_method_buffer_id,
-                                                  ALPROTO_HTTP);
+    return DetectEngineContentModifierBufferSetup(
+            de_ctx, s, str, DETECT_AL_HTTP_METHOD, g_http_method_buffer_id, ALPROTO_HTTP1);
 }
 
 /**
@@ -153,7 +148,7 @@ static int DetectHttpMethodSetup(DetectEngineCtx *de_ctx, Signature *s, const ch
  */
 static int DetectHttpMethodSetupSticky(DetectEngineCtx *de_ctx, Signature *s, const char *str)
 {
-    if (DetectBufferSetActiveList(s, g_http_method_buffer_id) < 0)
+    if (DetectBufferSetActiveList(de_ctx, s, g_http_method_buffer_id) < 0)
         return -1;
 
     if (DetectSignatureSetAppProto(s, ALPROTO_HTTP) < 0)
@@ -168,32 +163,36 @@ static int DetectHttpMethodSetupSticky(DetectEngineCtx *de_ctx, Signature *s, co
  */
 static bool DetectHttpMethodValidateCallback(const Signature *s, const char **sigerror)
 {
-    const SigMatch *sm = s->init_data->smlists[g_http_method_buffer_id];
-    for ( ; sm != NULL; sm = sm->next) {
-        if (sm->type != DETECT_CONTENT)
+    for (uint32_t x = 0; x < s->init_data->buffer_index; x++) {
+        if (s->init_data->buffers[x].id != (uint32_t)g_http_method_buffer_id)
             continue;
-        const DetectContentData *cd = (const DetectContentData *)sm->ctx;
-        if (cd->content && cd->content_len) {
-            if (cd->content[cd->content_len-1] == 0x20) {
-                *sigerror = "http_method pattern with trailing space";
-                SCLogError(SC_ERR_INVALID_SIGNATURE, "%s", *sigerror);
-                return FALSE;
-            } else if (cd->content[0] == 0x20) {
-                *sigerror = "http_method pattern with leading space";
-                SCLogError(SC_ERR_INVALID_SIGNATURE, "%s", *sigerror);
-                return FALSE;
-            } else if (cd->content[cd->content_len-1] == 0x09) {
-                *sigerror = "http_method pattern with trailing tab";
-                SCLogError(SC_ERR_INVALID_SIGNATURE, "%s", *sigerror);
-                return FALSE;
-            } else if (cd->content[0] == 0x09) {
-                *sigerror = "http_method pattern with leading tab";
-                SCLogError(SC_ERR_INVALID_SIGNATURE, "%s", *sigerror);
-                return FALSE;
+        const SigMatch *sm = s->init_data->buffers[x].head;
+        for (; sm != NULL; sm = sm->next) {
+            if (sm->type != DETECT_CONTENT)
+                continue;
+            const DetectContentData *cd = (const DetectContentData *)sm->ctx;
+            if (cd->content && cd->content_len) {
+                if (cd->content[cd->content_len - 1] == 0x20) {
+                    *sigerror = "http_method pattern with trailing space";
+                    SCLogError("%s", *sigerror);
+                    return false;
+                } else if (cd->content[0] == 0x20) {
+                    *sigerror = "http_method pattern with leading space";
+                    SCLogError("%s", *sigerror);
+                    return false;
+                } else if (cd->content[cd->content_len - 1] == 0x09) {
+                    *sigerror = "http_method pattern with trailing tab";
+                    SCLogError("%s", *sigerror);
+                    return false;
+                } else if (cd->content[0] == 0x09) {
+                    *sigerror = "http_method pattern with leading tab";
+                    SCLogError("%s", *sigerror);
+                    return false;
+                }
             }
         }
     }
-    return TRUE;
+    return true;
 }
 
 static InspectionBuffer *GetData(DetectEngineThreadCtx *det_ctx,
